kombu.transport — Kombu v1.3.2 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v1.3.2 documentation »
- API Reference »

# kombu.transport

Built-in transports.

copyright: | 2009 - 2011 by Ask Solem.
license: | BSD, see LICENSE for more details.

- Data
- Functions

## Data

`kombu.transport.` `DEFAULT_TRANSPORT`

  Default transport used when no transport specified.

`kombu.transport.` `TRANSPORT_ALIASES`

  Mapping of transport aliases/class names.

## Functions

`kombu.transport.` `get_transport_cls`(transport=None)

  Get transport class by name.

  The transport string is the full path to a transport class, e.g.:

      "kombu.transport.pyamqplib.Transport"

  If the name does not include ”.” (is not fully qualified), the alias table will be consulted.

`kombu.transport.` `resolve_transport`(transport=None)

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v1.3.2 documentation »
- API Reference »